package test;

import com.gyee.SpringbootStart;
import com.gyee.frame.common.spring.SpringUtils;
import com.gyee.frame.controller.health.HealthOperationController;
import lombok.SneakyThrows;
import org.springframework.boot.SpringApplication;

import java.util.Calendar;
import java.util.Date;
import java.util.Map;

public class HealthOperationTest {

    @SneakyThrows
    public static void main(String[] args) {

        SpringApplication.run(SpringbootStart.class, args);


        Calendar c = Calendar.getInstance();

        c.set(Calendar.HOUR_OF_DAY, 0);
        c.set(Calendar.MINUTE, 0);
        c.set(Calendar.SECOND, 0);
        c.set(Calendar.MILLISECOND, 0);
        c.set(Calendar.DAY_OF_MONTH,24);
        c.set(Calendar.MONTH,2);
        c.set(Calendar.YEAR,2021);

        Date date = c.getTime();

        String wtid="MG01_01";
        HealthOperationController healthOperationController= SpringUtils.getBean("healthOperationController");


//        Map<String, Object> map =healthOperationController.countStop("1");
//        Map<String, Object> map2 =healthOperationController.countWpwarn("1");
//        Map<String, Object> map3 =healthOperationController.countWpOrProStatus("1");
        Map<String, Object> map4 =healthOperationController.findWpOrProStatusForHistory("1","1");
        Map<String, Object> map5 =healthOperationController.findWpOrProStatusForHistory("1","2");
//        System.out.println(map);


        Map<String, Object> map =healthOperationController.countStop("2");
        Map<String, Object> map2 =healthOperationController.countWpwarn("2");
        Map<String, Object> map3 =healthOperationController.countWpOrProStatus("2");
        Map<String, Object> map42 =healthOperationController.findWpOrProStatusForHistory("2","1");
        Map<String, Object> map52 =healthOperationController.findWpOrProStatusForHistory("2","2");
        System.out.println(map);
//
//        Map<String, Object> map =healthMainController.findWpMap("MHS_FDC");

//        Map<String, Object> map =healthMainController.findHealthMatrixMap();
//
//        System.out.println(map);
//
//
//        Map<String, Object> map =healthMainController.findWpMap("MHS_FDC");
//
//
//        System.out.println(map);
//
//        Map<String, Object> map =healthMainController.findHealthMatrixMap();
//
//
//        System.out.println(map);
//
//
//        Map<String, Object> map =healthSubController.findPartHealthInfo(wtid);
//
//
//        System.out.println(map);



//        Map<String, Object> map1 =healthSubController.initalGzjfx(wtid);
//        Map<String, Object> map2 =healthSubController.initalYjfx(wtid);
//        Map<String, Object> map3 =healthSubController.initalYxfx(wtid);
//        Map<String, Object> map4 =healthSubController.initalXnfx(wtid);
//        Map<String, Object> map5 =healthSubController.initalShutdown(wtid);
//        Map<String, Object> map6 =healthSubController.findJudgmentList(wtid);
//        Map<String, Object> map7 =healthSubController.findQxpcList(wtid);
//        Map<String, Object> map8 =healthSubController.findWdList(wtid);
//
//        Map<String, Object> map1 =healthSubController.gadaytop5(wtid);
//        Map<String, Object> map2 =healthSubController.queryStopTop10(wtid);
//        System.out.println(map1.size());


//        Map<String, Object> map1 =healthSubController.hsFjValueIndex(wtid);
//        System.out.println(map1.size());
        System.out.println("***************************************************************************************");


    }




}
